@@ -121,8 +121,8 @@ lazy_static! {
             .collect();
 
             let from_online = fetch_contract_val("swap");
-            for (pair, contract_value) in &from_online {
-                m.insert(pair.clone(), *contract_value);
+            for (pair, contract_value) in from_online {
+                m.insert(pair, contract_value);
             }
 
             m
